# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/chunk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%artifact/artifact/v1alpha/chunk.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfd\x01\n\x05\x43hunk\x12\x1b\n\tchunk_uid\x18\x01 \x01(\tR\x08\x63hunkUid\x12 \n\x0bretrievable\x18\x02 \x01(\x08R\x0bretrievable\x12\x1b\n\tstart_pos\x18\x04 \x01(\rR\x08startPos\x12\x17\n\x07\x65nd_pos\x18\x05 \x01(\rR\x06\x65ndPos\x12\x16\n\x06tokens\x18\x06 \x01(\rR\x06tokens\x12;\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12*\n\x11original_file_uid\x18\x08 \x01(\tR\x0foriginalFileUid\"f\n\x11ListChunksRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x13\n\x05kb_id\x18\x02 \x01(\tR\x04kbId\x12\x19\n\x08\x66ile_uid\x18\x03 \x01(\tR\x07\x66ileUid\"N\n\x12ListChunksResponse\x12\x38\n\x06\x63hunks\x18\x01 \x03(\x0b\x32 .artifact.artifact.v1alpha.ChunkR\x06\x63hunks\"\xcc\x01\n\nSourceFile\x12*\n\x11original_file_uid\x18\x01 \x01(\tR\x0foriginalFileUid\x12\x18\n\x07\x63ontent\x18\x03 \x01(\tR\x07\x63ontent\x12;\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12;\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\"i\n\x14GetSourceFileRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x13\n\x05kb_id\x18\x02 \x01(\tR\x04kbId\x12\x19\n\x08\x66ile_uid\x18\x03 \x01(\tR\x07\x66ileUid\"_\n\x15GetSourceFileResponse\x12\x46\n\x0bsource_file\x18\x01 \x01(\x0b\x32%.artifact.artifact.v1alpha.SourceFileR\nsourceFile\"S\n\x12UpdateChunkRequest\x12\x1b\n\tchunk_uid\x18\x01 \x01(\tR\x08\x63hunkUid\x12 \n\x0bretrievable\x18\x02 \x01(\x08R\x0bretrievable\"M\n\x13UpdateChunkResponse\x12\x36\n\x05\x63hunk\x18\x01 \x01(\x0b\x32 .artifact.artifact.v1alpha.ChunkR\x05\x63hunk\"\x8c\x01\n\x1dSimilarityChunksSearchRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x13\n\x05kb_id\x18\x02 \x01(\tR\x04kbId\x12\x1f\n\x0btext_prompt\x18\x03 \x01(\tR\ntextPrompt\x12\x12\n\x04topk\x18\x04 \x01(\rR\x04topk\"s\n\x1eSimilarityChunksSearchResponse\x12Q\n\x0esimilar_chunks\x18\x01 \x03(\x0b\x32*.artifact.artifact.v1alpha.SimilarityChunkR\rsimilarChunks\"\x9d\x01\n\x0fSimilarityChunk\x12\x1b\n\tchunk_uid\x18\x01 \x01(\tR\x08\x63hunkUid\x12)\n\x10similarity_score\x18\x02 \x01(\x02R\x0fsimilarityScore\x12!\n\x0ctext_content\x18\x03 \x01(\tR\x0btextContent\x12\x1f\n\x0bsource_file\x18\x04 \x01(\tR\nsourceFileB\xfe\x01\n\x1d\x63om.artifact.artifact.v1alphaB\nChunkProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.chunk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\nChunkProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _globals['_CHUNK']._serialized_start=102
  _globals['_CHUNK']._serialized_end=355
  _globals['_LISTCHUNKSREQUEST']._serialized_start=357
  _globals['_LISTCHUNKSREQUEST']._serialized_end=459
  _globals['_LISTCHUNKSRESPONSE']._serialized_start=461
  _globals['_LISTCHUNKSRESPONSE']._serialized_end=539
  _globals['_SOURCEFILE']._serialized_start=542
  _globals['_SOURCEFILE']._serialized_end=746
  _globals['_GETSOURCEFILEREQUEST']._serialized_start=748
  _globals['_GETSOURCEFILEREQUEST']._serialized_end=853
  _globals['_GETSOURCEFILERESPONSE']._serialized_start=855
  _globals['_GETSOURCEFILERESPONSE']._serialized_end=950
  _globals['_UPDATECHUNKREQUEST']._serialized_start=952
  _globals['_UPDATECHUNKREQUEST']._serialized_end=1035
  _globals['_UPDATECHUNKRESPONSE']._serialized_start=1037
  _globals['_UPDATECHUNKRESPONSE']._serialized_end=1114
  _globals['_SIMILARITYCHUNKSSEARCHREQUEST']._serialized_start=1117
  _globals['_SIMILARITYCHUNKSSEARCHREQUEST']._serialized_end=1257
  _globals['_SIMILARITYCHUNKSSEARCHRESPONSE']._serialized_start=1259
  _globals['_SIMILARITYCHUNKSSEARCHRESPONSE']._serialized_end=1374
  _globals['_SIMILARITYCHUNK']._serialized_start=1377
  _globals['_SIMILARITYCHUNK']._serialized_end=1534
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_image_to_image.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-model/model/v1alpha/task_image_to_image.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa3\x03\n\x11ImageToImageInput\x12*\n\x10prompt_image_url\x18\x01 \x01(\tH\x00R\x0epromptImageUrl\x12\x30\n\x13prompt_image_base64\x18\x02 \x01(\tH\x00R\x11promptImageBase64\x12!\n\x06prompt\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02H\x01R\x06prompt\x88\x01\x01\x12\x1f\n\x05steps\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x02R\x05steps\x88\x01\x01\x12&\n\tcfg_scale\x18\x05 \x01(\x02\x42\x04\xe2\x41\x01\x01H\x03R\x08\x63\x66gScale\x88\x01\x01\x12\x1d\n\x04seed\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x04R\x04seed\x88\x01\x01\x12#\n\x07samples\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x05R\x07samples\x88\x01\x01\x12@\n\x0c\x65xtra_params\x18\t \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x01R\x0b\x65xtraParamsB\x06\n\x04typeB\t\n\x07_promptB\x08\n\x06_stepsB\x0c\n\n_cfg_scaleB\x07\n\x05_seedB\n\n\x08_samples\"2\n\x12ImageToImageOutput\x12\x1c\n\x06images\x18\x01 \x03(\tB\x04\xe2\x41\x01\x03R\x06imagesB\xe2\x01\n\x17\x63om.model.model.v1alphaB\x15TaskImageToImageProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_image_to_image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\025TaskImageToImageProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _IMAGETOIMAGEINPUT.fields_by_name['prompt']._options = None
  _IMAGETOIMAGEINPUT.fields_by_name['prompt']._serialized_options = b'\342A\001\002'
  _IMAGETOIMAGEINPUT.fields_by_name['steps']._options = None
  _IMAGETOIMAGEINPUT.fields_by_name['steps']._serialized_options = b'\342A\001\001'
  _IMAGETOIMAGEINPUT.fields_by_name['cfg_scale']._options = None
  _IMAGETOIMAGEINPUT.fields_by_name['cfg_scale']._serialized_options = b'\342A\001\001'
  _IMAGETOIMAGEINPUT.fields_by_name['seed']._options = None
  _IMAGETOIMAGEINPUT.fields_by_name['seed']._serialized_options = b'\342A\001\001'
  _IMAGETOIMAGEINPUT.fields_by_name['samples']._options = None
  _IMAGETOIMAGEINPUT.fields_by_name['samples']._serialized_options = b'\342A\001\001'
  _IMAGETOIMAGEINPUT.fields_by_name['extra_params']._options = None
  _IMAGETOIMAGEINPUT.fields_by_name['extra_params']._serialized_options = b'\342A\001\001'
  _IMAGETOIMAGEOUTPUT.fields_by_name['images']._options = None
  _IMAGETOIMAGEOUTPUT.fields_by_name['images']._serialized_options = b'\342A\001\003'
  _globals['_IMAGETOIMAGEINPUT']._serialized_start=134
  _globals['_IMAGETOIMAGEINPUT']._serialized_end=553
  _globals['_IMAGETOIMAGEOUTPUT']._serialized_start=555
  _globals['_IMAGETOIMAGEOUTPUT']._serialized_end=605
# @@protoc_insertion_point(module_scope)



import os

IGNORE_FILES = {
    ".bash_logout",
    ".bashrc",
    ".profile",
    ".sudo_as_admin_successful",
    "pip-freeze.txt",
    "requirements_compiled.txt",
}

IGNORE_FOLDERS = {
    ".cache",
    ".conda",
    ".whl",
    "anaconda3",
}


def get_dir_size(path):
    total = 0
    with os.scandir(path) as it:
        for entry in it:
            if entry.is_file():
                if entry.name in IGNORE_FILES:
                    continue
                total += entry.stat().st_size
            elif entry.is_dir():
                if entry.name in IGNORE_FOLDERS:
                    continue
                total += get_dir_size(entry.path)
    return total



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import common.healthcheck.v1beta.healthcheck_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FileProcessStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FileProcessStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FileProcessStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FILE_PROCESS_STATUS_UNSPECIFIED: _FileProcessStatus.ValueType  # 0
    """UNSPECIFIED"""
    FILE_PROCESS_STATUS_NOTSTARTED: _FileProcessStatus.ValueType  # 1
    """NOTSTARTED"""
    FILE_PROCESS_STATUS_WAITING: _FileProcessStatus.ValueType  # 2
    """waiting"""
    FILE_PROCESS_STATUS_CONVERTING: _FileProcessStatus.ValueType  # 3
    """embedding process is running"""
    FILE_PROCESS_STATUS_CHUNKING: _FileProcessStatus.ValueType  # 4
    """embedding process is done"""
    FILE_PROCESS_STATUS_EMBEDDING: _FileProcessStatus.ValueType  # 5
    """embedding process is failed"""
    FILE_PROCESS_STATUS_COMPLETED: _FileProcessStatus.ValueType  # 6
    """COMPLETED"""
    FILE_PROCESS_STATUS_FAILED: _FileProcessStatus.ValueType  # 7
    """Failed"""

class FileProcessStatus(_FileProcessStatus, metaclass=_FileProcessStatusEnumTypeWrapper):
    """file embedding process status"""

FILE_PROCESS_STATUS_UNSPECIFIED: FileProcessStatus.ValueType  # 0
"""UNSPECIFIED"""
FILE_PROCESS_STATUS_NOTSTARTED: FileProcessStatus.ValueType  # 1
"""NOTSTARTED"""
FILE_PROCESS_STATUS_WAITING: FileProcessStatus.ValueType  # 2
"""waiting"""
FILE_PROCESS_STATUS_CONVERTING: FileProcessStatus.ValueType  # 3
"""embedding process is running"""
FILE_PROCESS_STATUS_CHUNKING: FileProcessStatus.ValueType  # 4
"""embedding process is done"""
FILE_PROCESS_STATUS_EMBEDDING: FileProcessStatus.ValueType  # 5
"""embedding process is failed"""
FILE_PROCESS_STATUS_COMPLETED: FileProcessStatus.ValueType  # 6
"""COMPLETED"""
FILE_PROCESS_STATUS_FAILED: FileProcessStatus.ValueType  # 7
"""Failed"""
global___FileProcessStatus = FileProcessStatus

class _FileType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FileTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FileType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FILE_TYPE_UNSPECIFIED: _FileType.ValueType  # 0
    """upsecifid"""
    FILE_TYPE_TEXT: _FileType.ValueType  # 1
    """text"""
    FILE_TYPE_PDF: _FileType.ValueType  # 2
    """PDF"""
    FILE_TYPE_MARKDOWN: _FileType.ValueType  # 3
    """MARKDOWN"""
    FILE_TYPE_PNG: _FileType.ValueType  # 4
    """PNG"""
    FILE_TYPE_JPEG: _FileType.ValueType  # 5
    """JPEG"""
    FILE_TYPE_JPG: _FileType.ValueType  # 6
    """JPG"""

class FileType(_FileType, metaclass=_FileTypeEnumTypeWrapper):
    """file type"""

FILE_TYPE_UNSPECIFIED: FileType.ValueType  # 0
"""upsecifid"""
FILE_TYPE_TEXT: FileType.ValueType  # 1
"""text"""
FILE_TYPE_PDF: FileType.ValueType  # 2
"""PDF"""
FILE_TYPE_MARKDOWN: FileType.ValueType  # 3
"""MARKDOWN"""
FILE_TYPE_PNG: FileType.ValueType  # 4
"""PNG"""
FILE_TYPE_JPEG: FileType.ValueType  # 5
"""JPEG"""
FILE_TYPE_JPG: FileType.ValueType  # 6
"""JPG"""
global___FileType = FileType

@typing_extensions.final
class LivenessRequest(google.protobuf.message.Message):
    """LivenessRequest represents a request to check a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___LivenessRequest = LivenessRequest

@typing_extensions.final
class LivenessResponse(google.protobuf.message.Message):
    """LivenessResponse represents a response for a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___LivenessResponse = LivenessResponse

@typing_extensions.final
class ReadinessRequest(google.protobuf.message.Message):
    """ReadinessRequest represents a request to check a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___ReadinessRequest = ReadinessRequest

@typing_extensions.final
class ReadinessResponse(google.protobuf.message.Message):
    """ReadinessResponse represents a response for a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___ReadinessResponse = ReadinessResponse

@typing_extensions.final
class RepositoryTag(google.protobuf.message.Message):
    """

    This API is under development and, therefore, some of its entitites and
    entpoints are not implemented yet. This section aims to give context about the
    current interface and how it fits in the Artifact vision.

    # Artifact

    The Artifact domain is responsible of storing data that will later be used for
    processing unstructured data. Artifact will support the following types of
    data:

    - Repositories
    - Objects
    - Vectors

    ## Repositories

    An implementation of the [OCI Distribution Specification](https://github.com/opencontainers/distribution-spec?tab=readme-ov-file)
    is used to manage versioned content. The main use for repositories is storing
    container images that can be used to deploy AI models or VDP pipelines.

    The ID of a repository has 2 segments, the owner (an Instill user or
    organization) and the content ID (the AI model or pipeline ID), e.g.
    `curious-wombat/llava-34b`.

    ## Objects

    Raw data is stored in binary blobs. Object storage allows users to upload data
    (e.g. images, audio) that can be used by pipelines or to store the results or a
    pipeline trigger.

    ## Vectors

    Vector embeddings have their own storage, which allows fast retrieval and similarity search.

    RepositoryTag contains information about the version of some content in a
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the tag, defined by its parent repository and ID.
    - Format: `repositories/{repository.id}/tags/{tag.id}`.
    """
    id: builtins.str
    """The tag identifier."""
    digest: builtins.str
    """The Artifact backend will register the tag digest and timestamp when a
    new version is pushed. However, the registry remains the source of truth
    for tags, so if this information isn't found in the Artifact database,
    these fields will be empty.

    Unique identifier, computed from the manifest the tag refers to.
    """
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Tag update time, i.e. timestamp of the last push."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
        digest: builtins.str = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest", b"digest", "id", b"id", "name", b"name", "update_time", b"update_time"]) -> None: ...

global___RepositoryTag = RepositoryTag

@typing_extensions.final
class ListRepositoryTagsRequest(google.protobuf.message.Message):
    """ListRepositoryTagsRequest represents a request to list the tags of a
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of tags to return. The default and cap values are 10
    and 100, respectively.
    """
    page: builtins.int
    """Page number."""
    parent: builtins.str
    """The repository holding the different versions of a given content.
    - Format: `repositories/{repository.id}`.
    - Example: `repositories/flaming-wombat/llama-2-7b`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page: builtins.int | None = ...,
        parent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_page", b"_page", "_page_size", b"_page_size", "page", b"page", "page_size", b"page_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_page", b"_page", "_page_size", b"_page_size", "page", b"page", "page_size", b"page_size", "parent", b"parent"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page", b"_page"]) -> typing_extensions.Literal["page"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...

global___ListRepositoryTagsRequest = ListRepositoryTagsRequest

@typing_extensions.final
class ListRepositoryTagsResponse(google.protobuf.message.Message):
    """ListRepositoryTagsResponse contains a list of container image tags."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAGS_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RepositoryTag]:
        """A list of repository tags."""
    total_size: builtins.int
    """Total number of tags."""
    page_size: builtins.int
    """The requested page size."""
    page: builtins.int
    """The requested page offset."""
    def __init__(
        self,
        *,
        tags: collections.abc.Iterable[global___RepositoryTag] | None = ...,
        total_size: builtins.int = ...,
        page_size: builtins.int = ...,
        page: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page", b"page", "page_size", b"page_size", "tags", b"tags", "total_size", b"total_size"]) -> None: ...

global___ListRepositoryTagsResponse = ListRepositoryTagsResponse

@typing_extensions.final
class CreateRepositoryTagRequest(google.protobuf.message.Message):
    """CreateRepositoryTagRequest represents a request to add a tag to a given
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    @property
    def tag(self) -> global___RepositoryTag:
        """The tag information."""
    def __init__(
        self,
        *,
        tag: global___RepositoryTag | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> None: ...

global___CreateRepositoryTagRequest = CreateRepositoryTagRequest

@typing_extensions.final
class CreateRepositoryTagResponse(google.protobuf.message.Message):
    """CreateRepositoryTagResponse contains the created tag."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    @property
    def tag(self) -> global___RepositoryTag:
        """The created tag."""
    def __init__(
        self,
        *,
        tag: global___RepositoryTag | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> None: ...

global___CreateRepositoryTagResponse = CreateRepositoryTagResponse

@typing_extensions.final
class GetRepositoryTagRequest(google.protobuf.message.Message):
    """GetRepositoryTagRequest represents a request to add a tag to a given
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the tag, defined by its parent repository and ID.
    - Format: `repositories/{repository.id}/tags/{tag.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetRepositoryTagRequest = GetRepositoryTagRequest

@typing_extensions.final
class GetRepositoryTagResponse(google.protobuf.message.Message):
    """GetRepositoryTagResponse contains the created tag."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    @property
    def tag(self) -> global___RepositoryTag:
        """The created tag."""
    def __init__(
        self,
        *,
        tag: global___RepositoryTag | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> None: ...

global___GetRepositoryTagResponse = GetRepositoryTagResponse

@typing_extensions.final
class DeleteRepositoryTagRequest(google.protobuf.message.Message):
    """DeleteRepositoryTagRequest represents a request to delete a tag to a given
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the tag, defined by its parent repository and ID.
    - Format: `repositories/{repository.id}/tags/{tag.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteRepositoryTagRequest = DeleteRepositoryTagRequest

@typing_extensions.final
class DeleteRepositoryTagResponse(google.protobuf.message.Message):
    """DeleteRepositoryTagResponse represent an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteRepositoryTagResponse = DeleteRepositoryTagResponse

@typing_extensions.final
class KnowledgeBase(google.protobuf.message.Message):
    """KnowledgeBase represents a knowledge base."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KB_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    OWNER_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CONVERTING_PIPELINES_FIELD_NUMBER: builtins.int
    SPLITTING_PIPELINES_FIELD_NUMBER: builtins.int
    EMBEDDING_PIPELINES_FIELD_NUMBER: builtins.int
    DOWNSTREAM_APPS_FIELD_NUMBER: builtins.int
    TOTAL_FILES_FIELD_NUMBER: builtins.int
    TOTAL_TOKENS_FIELD_NUMBER: builtins.int
    USED_STORAGE_FIELD_NUMBER: builtins.int
    kb_id: builtins.str
    """The knowledge base identifier."""
    name: builtins.str
    """The knowledge base name."""
    description: builtins.str
    """The knowledge base description."""
    create_time: builtins.str
    """The creation time of the knowledge base."""
    update_time: builtins.str
    """The last update time of the knowledge base."""
    owner_name: builtins.str
    """The owner of the knowledge base."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The knowledge base tags."""
    @property
    def converting_pipelines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The knowledge base converting pipelines."""
    @property
    def splitting_pipelines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The knowledge base splitting pipelines."""
    @property
    def embedding_pipelines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The knowledge base embedding pipelines."""
    @property
    def downstream_apps(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The downstream apps"""
    total_files: builtins.int
    """The total files in knowledge base."""
    total_tokens: builtins.int
    """The total tokens in knowledge base."""
    used_storage: builtins.int
    """The current used storage in knowledge base."""
    def __init__(
        self,
        *,
        kb_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        create_time: builtins.str = ...,
        update_time: builtins.str = ...,
        owner_name: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        converting_pipelines: collections.abc.Iterable[builtins.str] | None = ...,
        splitting_pipelines: collections.abc.Iterable[builtins.str] | None = ...,
        embedding_pipelines: collections.abc.Iterable[builtins.str] | None = ...,
        downstream_apps: collections.abc.Iterable[builtins.str] | None = ...,
        total_files: builtins.int = ...,
        total_tokens: builtins.int = ...,
        used_storage: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["converting_pipelines", b"converting_pipelines", "create_time", b"create_time", "description", b"description", "downstream_apps", b"downstream_apps", "embedding_pipelines", b"embedding_pipelines", "kb_id", b"kb_id", "name", b"name", "owner_name", b"owner_name", "splitting_pipelines", b"splitting_pipelines", "tags", b"tags", "total_files", b"total_files", "total_tokens", b"total_tokens", "update_time", b"update_time", "used_storage", b"used_storage"]) -> None: ...

global___KnowledgeBase = KnowledgeBase

@typing_extensions.final
class CreateKnowledgeBaseRequest(google.protobuf.message.Message):
    """CreateKnowledgeBaseRequest represents a request to create a knowledge base."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The knowledge base owner(nammespace)."""
    name: builtins.str
    """The knowledge base name."""
    description: builtins.str
    """The knowledge base description."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The knowledge base tags."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "namespace_id", b"namespace_id", "tags", b"tags"]) -> None: ...

global___CreateKnowledgeBaseRequest = CreateKnowledgeBaseRequest

@typing_extensions.final
class CreateKnowledgeBaseResponse(google.protobuf.message.Message):
    """CreateKnowledgeBaseResponse represents a response for creating a knowledge base."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KNOWLEDGE_BASE_FIELD_NUMBER: builtins.int
    @property
    def knowledge_base(self) -> global___KnowledgeBase:
        """The created knowledge base."""
    def __init__(
        self,
        *,
        knowledge_base: global___KnowledgeBase | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["knowledge_base", b"knowledge_base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["knowledge_base", b"knowledge_base"]) -> None: ...

global___CreateKnowledgeBaseResponse = CreateKnowledgeBaseResponse

@typing_extensions.final
class ListKnowledgeBasesRequest(google.protobuf.message.Message):
    """Request message for ListKnowledgeBases"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """User ID for which to list the knowledge bases"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id"]) -> None: ...

global___ListKnowledgeBasesRequest = ListKnowledgeBasesRequest

@typing_extensions.final
class ListKnowledgeBasesResponse(google.protobuf.message.Message):
    """GetKnowledgeBasesResponse represents a response for getting all knowledge bases from users."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KNOWLEDGE_BASES_FIELD_NUMBER: builtins.int
    @property
    def knowledge_bases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KnowledgeBase]:
        """The knowledge bases container."""
    def __init__(
        self,
        *,
        knowledge_bases: collections.abc.Iterable[global___KnowledgeBase] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["knowledge_bases", b"knowledge_bases"]) -> None: ...

global___ListKnowledgeBasesResponse = ListKnowledgeBasesResponse

@typing_extensions.final
class UpdateKnowledgeBaseRequest(google.protobuf.message.Message):
    """UpdateKnowledgeBaseRequest represents a request to update a knowledge base."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KB_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    kb_id: builtins.str
    """The knowledge base id."""
    description: builtins.str
    """The knowledge base description."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The knowledge base tags."""
    namespace_id: builtins.str
    """The knowledge base owner(namespace)."""
    def __init__(
        self,
        *,
        kb_id: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        namespace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "kb_id", b"kb_id", "namespace_id", b"namespace_id", "tags", b"tags"]) -> None: ...

global___UpdateKnowledgeBaseRequest = UpdateKnowledgeBaseRequest

@typing_extensions.final
class UpdateKnowledgeBaseResponse(google.protobuf.message.Message):
    """UpdateKnowledgeBaseResponse represents a response for updating a knowledge base."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KNOWLEDGE_BASE_FIELD_NUMBER: builtins.int
    @property
    def knowledge_base(self) -> global___KnowledgeBase:
        """The updated knowledge base."""
    def __init__(
        self,
        *,
        knowledge_base: global___KnowledgeBase | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["knowledge_base", b"knowledge_base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["knowledge_base", b"knowledge_base"]) -> None: ...

global___UpdateKnowledgeBaseResponse = UpdateKnowledgeBaseResponse

@typing_extensions.final
class DeleteKnowledgeBaseRequest(google.protobuf.message.Message):
    """DeleteKnowledgeBaseRequest represents a request to delete a knowledge base."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    KB_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The owner's id. i.e. namespace."""
    kb_id: builtins.str
    """The knowledge base identifier."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        kb_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kb_id", b"kb_id", "namespace_id", b"namespace_id"]) -> None: ...

global___DeleteKnowledgeBaseRequest = DeleteKnowledgeBaseRequest

@typing_extensions.final
class DeleteKnowledgeBaseResponse(google.protobuf.message.Message):
    """DeleteKnowledgeBaseResponse represents a response for deleting a knowledge base."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KNOWLEDGE_BASE_FIELD_NUMBER: builtins.int
    @property
    def knowledge_base(self) -> global___KnowledgeBase:
        """The knowledge base identifier."""
    def __init__(
        self,
        *,
        knowledge_base: global___KnowledgeBase | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["knowledge_base", b"knowledge_base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["knowledge_base", b"knowledge_base"]) -> None: ...

global___DeleteKnowledgeBaseResponse = DeleteKnowledgeBaseResponse

@typing_extensions.final
class File(google.protobuf.message.Message):
    """file mata data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PROCESS_STATUS_FIELD_NUMBER: builtins.int
    PROCESS_OUTCOME_FIELD_NUMBER: builtins.int
    RETRIEVABLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    OWNER_UID_FIELD_NUMBER: builtins.int
    CREATOR_UID_FIELD_NUMBER: builtins.int
    KB_UID_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    DELETE_TIME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TOTAL_CHUNKS_FIELD_NUMBER: builtins.int
    TOTAL_TOKENS_FIELD_NUMBER: builtins.int
    file_uid: builtins.str
    """file uid"""
    name: builtins.str
    """file name"""
    type: global___FileType.ValueType
    """file type"""
    process_status: global___FileProcessStatus.ValueType
    """file process status"""
    process_outcome: builtins.str
    """file process message"""
    retrievable: builtins.bool
    """retrievable(this is reserved for future use)"""
    content: builtins.str
    """contect(this is reserved for future use)"""
    owner_uid: builtins.str
    """owner uid"""
    creator_uid: builtins.str
    """cretor uid from authn token"""
    kb_uid: builtins.str
    """knowledge base uid"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """create time"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """update time"""
    @property
    def delete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """delete time"""
    size: builtins.int
    """file size in bytes"""
    total_chunks: builtins.int
    """total chunks"""
    total_tokens: builtins.int
    """total tokens"""
    def __init__(
        self,
        *,
        file_uid: builtins.str = ...,
        name: builtins.str = ...,
        type: global___FileType.ValueType = ...,
        process_status: global___FileProcessStatus.ValueType = ...,
        process_outcome: builtins.str = ...,
        retrievable: builtins.bool = ...,
        content: builtins.str = ...,
        owner_uid: builtins.str = ...,
        creator_uid: builtins.str = ...,
        kb_uid: builtins.str = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        delete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        size: builtins.int = ...,
        total_chunks: builtins.int = ...,
        total_tokens: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "delete_time", b"delete_time", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "create_time", b"create_time", "creator_uid", b"creator_uid", "delete_time", b"delete_time", "file_uid", b"file_uid", "kb_uid", b"kb_uid", "name", b"name", "owner_uid", b"owner_uid", "process_outcome", b"process_outcome", "process_status", b"process_status", "retrievable", b"retrievable", "size", b"size", "total_chunks", b"total_chunks", "total_tokens", b"total_tokens", "type", b"type", "update_time", b"update_time"]) -> None: ...

global___File = File

@typing_extensions.final
class UploadKnowledgeBaseFileRequest(google.protobuf.message.Message):
    """upload file request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    KB_ID_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owenr uid"""
    kb_id: builtins.str
    """knowledge base uid"""
    @property
    def file(self) -> global___File:
        """file"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        kb_id: builtins.str = ...,
        file: global___File | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "kb_id", b"kb_id", "namespace_id", b"namespace_id"]) -> None: ...

global___UploadKnowledgeBaseFileRequest = UploadKnowledgeBaseFileRequest

@typing_extensions.final
class UploadKnowledgeBaseFileResponse(google.protobuf.message.Message):
    """upload file response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    @property
    def file(self) -> global___File:
        """file"""
    def __init__(
        self,
        *,
        file: global___File | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file"]) -> None: ...

global___UploadKnowledgeBaseFileResponse = UploadKnowledgeBaseFileResponse

@typing_extensions.final
class DeleteKnowledgeBaseFileRequest(google.protobuf.message.Message):
    """delete file request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UID_FIELD_NUMBER: builtins.int
    file_uid: builtins.str
    """The file uid."""
    def __init__(
        self,
        *,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uid", b"file_uid"]) -> None: ...

global___DeleteKnowledgeBaseFileRequest = DeleteKnowledgeBaseFileRequest

@typing_extensions.final
class DeleteKnowledgeBaseFileResponse(google.protobuf.message.Message):
    """delete file response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UID_FIELD_NUMBER: builtins.int
    file_uid: builtins.str
    """The file uid."""
    def __init__(
        self,
        *,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uid", b"file_uid"]) -> None: ...

global___DeleteKnowledgeBaseFileResponse = DeleteKnowledgeBaseFileResponse

@typing_extensions.final
class ProcessKnowledgeBaseFilesRequest(google.protobuf.message.Message):
    """Process KnowledgeBase File Request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UIDS_FIELD_NUMBER: builtins.int
    @property
    def file_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The file uid."""
    def __init__(
        self,
        *,
        file_uids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uids", b"file_uids"]) -> None: ...

global___ProcessKnowledgeBaseFilesRequest = ProcessKnowledgeBaseFilesRequest

@typing_extensions.final
class ProcessKnowledgeBaseFilesResponse(google.protobuf.message.Message):
    """Process KnowledgeBase File Response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """The file uid."""
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[global___File] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files"]) -> None: ...

global___ProcessKnowledgeBaseFilesResponse = ProcessKnowledgeBaseFilesResponse

@typing_extensions.final
class ListKnowledgeBaseFilesFilter(google.protobuf.message.Message):
    """list file filter
    todo: support more parameters
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UIDS_FIELD_NUMBER: builtins.int
    @property
    def file_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The file uids."""
    def __init__(
        self,
        *,
        file_uids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uids", b"file_uids"]) -> None: ...

global___ListKnowledgeBaseFilesFilter = ListKnowledgeBaseFilesFilter

@typing_extensions.final
class ListKnowledgeBaseFilesRequest(google.protobuf.message.Message):
    """list files request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    KB_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The owner uid."""
    kb_id: builtins.str
    """The knowledge base uid."""
    page_size: builtins.int
    """The page size (default:10; max 100)."""
    page_token: builtins.str
    """The next page token(default from first file's token)."""
    @property
    def filter(self) -> global___ListKnowledgeBaseFilesFilter:
        """The filter."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        kb_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: global___ListKnowledgeBaseFilesFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter", "kb_id", b"kb_id", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListKnowledgeBaseFilesRequest = ListKnowledgeBaseFilesRequest

@typing_extensions.final
class ListKnowledgeBaseFilesResponse(google.protobuf.message.Message):
    """list files response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """The list of files."""
    total_size: builtins.int
    """The total number of files."""
    page_size: builtins.int
    """The requested page size."""
    next_page_token: builtins.str
    """next page token"""
    @property
    def filter(self) -> global___ListKnowledgeBaseFilesFilter:
        """The filter."""
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[global___File] | None = ...,
        total_size: builtins.int = ...,
        page_size: builtins.int = ...,
        next_page_token: builtins.str = ...,
        filter: global___ListKnowledgeBaseFilesFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files", "filter", b"filter", "next_page_token", b"next_page_token", "page_size", b"page_size", "total_size", b"total_size"]) -> None: ...

global___ListKnowledgeBaseFilesResponse = ListKnowledgeBaseFilesResponse



import instill.protogen.common.task.v1alpha.task_pb2 as task
import instill.protogen.model.model.v1alpha.model_pb2 as model_pb
import instill.protogen.model.model.v1alpha.task_classification_pb2 as task_classification
import instill.protogen.model.model.v1alpha.task_detection_pb2 as task_detection
import instill.protogen.model.model.v1alpha.task_keypoint_pb2 as task_keypoint
import instill.protogen.model.model.v1alpha.task_ocr_pb2 as task_ocr
import instill.protogen.model.model.v1alpha.task_semantic_segmentation_pb2 as task_semantic_segmentation
import instill.protogen.model.model.v1alpha.task_text_generation_pb2 as task_text_generation
import instill.protogen.model.model.v1alpha.task_text_to_image_pb2 as task_text_to_image
import instill.protogen.vdp.pipeline.v1beta.pipeline_pb2 as pipeline_pb

# from instill.resources.connector_ai import (
#     HuggingfaceConnector,
#     InstillModelConnector,
#     OpenAIConnector,
#     StabilityAIConnector,
# )
# from instill.resources.connector_blockchain import NumbersConnector
# from instill.resources.connector_data import (
#     BigQueryConnector,
#     GoogleCloudStorageConnector,
#     GoogleSearchConnector,
#     PineconeConnector,
#     RedisConnector,
#     WebsiteConnector,
# )
# from instill.resources.operator import (
#     Base64Operator,
#     ImageOperator,
#     JSONOperator,
#     TextOperator,
# )
from instill.resources.model import Model
from instill.resources.pipeline import Pipeline



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TextToImageInput(google.protobuf.message.Message):
    """TextToImageInput represents the input of a text-to-image task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_FIELD_NUMBER: builtins.int
    PROMPT_IMAGE_URL_FIELD_NUMBER: builtins.int
    PROMPT_IMAGE_BASE64_FIELD_NUMBER: builtins.int
    STEPS_FIELD_NUMBER: builtins.int
    CFG_SCALE_FIELD_NUMBER: builtins.int
    SEED_FIELD_NUMBER: builtins.int
    SAMPLES_FIELD_NUMBER: builtins.int
    EXTRA_PARAMS_FIELD_NUMBER: builtins.int
    prompt: builtins.str
    """Prompt text."""
    prompt_image_url: builtins.str
    """Image URL."""
    prompt_image_base64: builtins.str
    """Base64-encoded image."""
    steps: builtins.int
    """Steps, defaults to 5."""
    cfg_scale: builtins.float
    """Guidance scale, defaults to 7.5."""
    seed: builtins.int
    """Seed, defaults to 0."""
    samples: builtins.int
    """Number of generated samples, default is 1."""
    @property
    def extra_params(self) -> google.protobuf.struct_pb2.Struct:
        """Extra parameters."""
    def __init__(
        self,
        *,
        prompt: builtins.str = ...,
        prompt_image_url: builtins.str = ...,
        prompt_image_base64: builtins.str = ...,
        steps: builtins.int | None = ...,
        cfg_scale: builtins.float | None = ...,
        seed: builtins.int | None = ...,
        samples: builtins.int | None = ...,
        extra_params: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_cfg_scale", b"_cfg_scale", "_samples", b"_samples", "_seed", b"_seed", "_steps", b"_steps", "cfg_scale", b"cfg_scale", "extra_params", b"extra_params", "prompt_image_base64", b"prompt_image_base64", "prompt_image_url", b"prompt_image_url", "samples", b"samples", "seed", b"seed", "steps", b"steps", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_cfg_scale", b"_cfg_scale", "_samples", b"_samples", "_seed", b"_seed", "_steps", b"_steps", "cfg_scale", b"cfg_scale", "extra_params", b"extra_params", "prompt", b"prompt", "prompt_image_base64", b"prompt_image_base64", "prompt_image_url", b"prompt_image_url", "samples", b"samples", "seed", b"seed", "steps", b"steps", "type", b"type"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_cfg_scale", b"_cfg_scale"]) -> typing_extensions.Literal["cfg_scale"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_samples", b"_samples"]) -> typing_extensions.Literal["samples"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_seed", b"_seed"]) -> typing_extensions.Literal["seed"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_steps", b"_steps"]) -> typing_extensions.Literal["steps"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["prompt_image_url", "prompt_image_base64"] | None: ...

global___TextToImageInput = TextToImageInput

@typing_extensions.final
class TextToImageOutput(google.protobuf.message.Message):
    """TextToImageOutput contains the result of a text-to-image task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGES_FIELD_NUMBER: builtins.int
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of generated images, encoded in base64."""
    def __init__(
        self,
        *,
        images: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["images", b"images"]) -> None: ...

global___TextToImageOutput = TextToImageOutput



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ReleaseStage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReleaseStageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReleaseStage.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RELEASE_STAGE_UNSPECIFIED: _ReleaseStage.ValueType  # 0
    """Unspecified."""
    RELEASE_STAGE_ALPHA: _ReleaseStage.ValueType  # 1
    """Alpha."""
    RELEASE_STAGE_BETA: _ReleaseStage.ValueType  # 2
    """Beta."""
    RELEASE_STAGE_GENERALLY_AVAILABLE: _ReleaseStage.ValueType  # 3
    """Generally available."""
    RELEASE_STAGE_CUSTOM: _ReleaseStage.ValueType  # 4
    """Custom."""

class ReleaseStage(_ReleaseStage, metaclass=_ReleaseStageEnumTypeWrapper):
    """/////////////////////////////////////////////////////////////////

    ReleaseStage defines the stage of a release.
    """

RELEASE_STAGE_UNSPECIFIED: ReleaseStage.ValueType  # 0
"""Unspecified."""
RELEASE_STAGE_ALPHA: ReleaseStage.ValueType  # 1
"""Alpha."""
RELEASE_STAGE_BETA: ReleaseStage.ValueType  # 2
"""Beta."""
RELEASE_STAGE_GENERALLY_AVAILABLE: ReleaseStage.ValueType  # 3
"""Generally available."""
RELEASE_STAGE_CUSTOM: ReleaseStage.ValueType  # 4
"""Custom."""
global___ReleaseStage = ReleaseStage

class _View:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_View.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VIEW_UNSPECIFIED: _View.ValueType  # 0
    """Unspecified, equivalent to BASIC."""
    VIEW_BASIC: _View.ValueType  # 1
    """Default view, only includes basic information (omits `model_spec`)."""
    VIEW_FULL: _View.ValueType  # 2
    """Full representation."""

class View(_View, metaclass=_ViewEnumTypeWrapper):
    """View defines how a model definition is presented."""

VIEW_UNSPECIFIED: View.ValueType  # 0
"""Unspecified, equivalent to BASIC."""
VIEW_BASIC: View.ValueType  # 1
"""Default view, only includes basic information (omits `model_spec`)."""
VIEW_FULL: View.ValueType  # 2
"""Full representation."""
global___View = View

@typing_extensions.final
class ModelDefinition(google.protobuf.message.Message):
    """/////////////////////////////////////////////////////////////////

    ModelDefinition defines how to configure and import a model.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DOCUMENTATION_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    RELEASE_STAGE_FIELD_NUMBER: builtins.int
    MODEL_SPEC_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the model, which allows its access by ID.
    - Format: `model-definitions/{id}`.
    """
    uid: builtins.str
    """Model definition UUID."""
    id: builtins.str
    """Model definition resource ID (used in `name` as the last segment). This
    conforms to RFC-1034, which restricts to letters, numbers, and hyphen,
    with the first character a letter, the last a letter or a number, and a 63
    character maximum.
    """
    title: builtins.str
    """Official display title."""
    documentation_url: builtins.str
    """Documentation URL."""
    icon: builtins.str
    """Display icon."""
    release_stage: global___ReleaseStage.ValueType
    """Release stage."""
    @property
    def model_spec(self) -> google.protobuf.struct_pb2.Struct:
        """The model specification represented by a JSON schema. It is used to
        validate the JSON configurations of a model created from a specific model
        source, and the resource spec which the model is desired to be deployed on.
        It must be a valid JSON that includes what fields are needed to
        create or display a model.
        """
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation time."""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Update time."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        title: builtins.str = ...,
        documentation_url: builtins.str = ...,
        icon: builtins.str = ...,
        release_stage: global___ReleaseStage.ValueType = ...,
        model_spec: google.protobuf.struct_pb2.Struct | None = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "model_spec", b"model_spec", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "documentation_url", b"documentation_url", "icon", b"icon", "id", b"id", "model_spec", b"model_spec", "name", b"name", "release_stage", b"release_stage", "title", b"title", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___ModelDefinition = ModelDefinition

@typing_extensions.final
class ListModelDefinitionsRequest(google.protobuf.message.Message):
    """ListModelDefinitionsRequest represents a request to list all supported model
    definitions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of model definitions to return. If this parameter
    is unspecified, at most 10 definitions will be returned. The cap value for
    this parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_page_size", b"_page_size", "_page_token", b"_page_token", "_view", b"_view", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_page_size", b"_page_size", "_page_token", b"_page_token", "_view", b"_view", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListModelDefinitionsRequest = ListModelDefinitionsRequest

@typing_extensions.final
class ListModelDefinitionsResponse(google.protobuf.message.Message):
    """ListModelDefinitionsResponse contains a list of model definitions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_DEFINITIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def model_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelDefinition]:
        """A list of model definition resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of model definitions."""
    def __init__(
        self,
        *,
        model_definitions: collections.abc.Iterable[global___ModelDefinition] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_definitions", b"model_definitions", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListModelDefinitionsResponse = ListModelDefinitionsResponse

@typing_extensions.final
class GetModelDefinitionRequest(google.protobuf.message.Message):
    """GetModelDefinitionRequest represents a request to fetch the details of a
    model definition.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_FIELD_NUMBER: builtins.int
    MODEL_DEFINITION_ID_FIELD_NUMBER: builtins.int
    view: global___View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    model_definition_id: builtins.str
    """The resource name of the model definition, which allows its access by ID.
    - Format: `model-definitions/{id}`.
    """
    def __init__(
        self,
        *,
        view: global___View.ValueType | None = ...,
        model_definition_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "model_definition_id", b"model_definition_id", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetModelDefinitionRequest = GetModelDefinitionRequest

@typing_extensions.final
class GetModelDefinitionResponse(google.protobuf.message.Message):
    """GetModelDefinitionResponse contains the requested model definition."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def model_definition(self) -> global___ModelDefinition:
        """The model definition resource."""
    def __init__(
        self,
        *,
        model_definition: global___ModelDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_definition", b"model_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_definition", b"model_definition"]) -> None: ...

global___GetModelDefinitionResponse = GetModelDefinitionResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/model_definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*model/model/v1alpha/model_definition.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xac\x04\n\x0fModelDefinition\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x02id\x12\x1a\n\x05title\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03R\x05title\x12\x31\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x64ocumentationUrl\x12\x18\n\x04icon\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x04icon\x12L\n\rrelease_stage\x18\x07 \x01(\x0e\x32!.model.model.v1alpha.ReleaseStageB\x04\xe2\x41\x01\x03R\x0creleaseStage\x12<\n\nmodel_spec\x18\x08 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\tmodelSpec\x12\x41\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime:V\xea\x41S\n api.instill.tech/ModelDefinition\x12\x16model-definitions/{id}\x12\x17model-definitions/{uid}\"\xcf\x01\n\x1bListModelDefinitionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_view\"\xb8\x01\n\x1cListModelDefinitionsResponse\x12Q\n\x11model_definitions\x18\x01 \x03(\x0b\x32$.model.model.v1alpha.ModelDefinitionR\x10modelDefinitions\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x9a\x01\n\x19GetModelDefinitionRequest\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x12\x34\n\x13model_definition_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x11modelDefinitionIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"s\n\x1aGetModelDefinitionResponse\x12U\n\x10model_definition\x18\x01 \x01(\x0b\x32$.model.model.v1alpha.ModelDefinitionB\x04\xe2\x41\x01\x03R\x0fmodelDefinition*\x9f\x01\n\x0cReleaseStage\x12\x1d\n\x19RELEASE_STAGE_UNSPECIFIED\x10\x00\x12\x17\n\x13RELEASE_STAGE_ALPHA\x10\x01\x12\x16\n\x12RELEASE_STAGE_BETA\x10\x02\x12%\n!RELEASE_STAGE_GENERALLY_AVAILABLE\x10\x03\x12\x18\n\x14RELEASE_STAGE_CUSTOM\x10\x04*;\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\x42\xe1\x01\n\x17\x63om.model.model.v1alphaB\x14ModelDefinitionProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.model_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\024ModelDefinitionProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _MODELDEFINITION.fields_by_name['name']._options = None
  _MODELDEFINITION.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['uid']._options = None
  _MODELDEFINITION.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['id']._options = None
  _MODELDEFINITION.fields_by_name['id']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['title']._options = None
  _MODELDEFINITION.fields_by_name['title']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['documentation_url']._options = None
  _MODELDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['icon']._options = None
  _MODELDEFINITION.fields_by_name['icon']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['release_stage']._options = None
  _MODELDEFINITION.fields_by_name['release_stage']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['model_spec']._options = None
  _MODELDEFINITION.fields_by_name['model_spec']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['create_time']._options = None
  _MODELDEFINITION.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION.fields_by_name['update_time']._options = None
  _MODELDEFINITION.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _MODELDEFINITION._options = None
  _MODELDEFINITION._serialized_options = b'\352AS\n api.instill.tech/ModelDefinition\022\026model-definitions/{id}\022\027model-definitions/{uid}'
  _LISTMODELDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTMODELDEFINITIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELDEFINITIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTMODELDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTMODELDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETMODELDEFINITIONREQUEST.fields_by_name['view']._options = None
  _GETMODELDEFINITIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETMODELDEFINITIONREQUEST.fields_by_name['model_definition_id']._options = None
  _GETMODELDEFINITIONREQUEST.fields_by_name['model_definition_id']._serialized_options = b'\342A\001\002'
  _GETMODELDEFINITIONRESPONSE.fields_by_name['model_definition']._options = None
  _GETMODELDEFINITIONRESPONSE.fields_by_name['model_definition']._serialized_options = b'\342A\001\003'
  _globals['_RELEASESTAGE']._serialized_start=1421
  _globals['_RELEASESTAGE']._serialized_end=1580
  _globals['_VIEW']._serialized_start=1582
  _globals['_VIEW']._serialized_end=1641
  _globals['_MODELDEFINITION']._serialized_start=191
  _globals['_MODELDEFINITION']._serialized_end=747
  _globals['_LISTMODELDEFINITIONSREQUEST']._serialized_start=750
  _globals['_LISTMODELDEFINITIONSREQUEST']._serialized_end=957
  _globals['_LISTMODELDEFINITIONSRESPONSE']._serialized_start=960
  _globals['_LISTMODELDEFINITIONSRESPONSE']._serialized_end=1144
  _globals['_GETMODELDEFINITIONREQUEST']._serialized_start=1147
  _globals['_GETMODELDEFINITIONREQUEST']._serialized_end=1301
  _globals['_GETMODELDEFINITIONRESPONSE']._serialized_start=1303
  _globals['_GETMODELDEFINITIONRESPONSE']._serialized_end=1418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/artifact_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8artifact/artifact/v1alpha/artifact_private_service.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a(artifact/artifact/v1alpha/artifact.proto2\xa7\x04\n\x16\x41rtifactPrivateService\x12\x81\x01\n\x12ListRepositoryTags\x12\x34.artifact.artifact.v1alpha.ListRepositoryTagsRequest\x1a\x35.artifact.artifact.v1alpha.ListRepositoryTagsResponse\x12{\n\x10GetRepositoryTag\x12\x32.artifact.artifact.v1alpha.GetRepositoryTagRequest\x1a\x33.artifact.artifact.v1alpha.GetRepositoryTagResponse\x12\x84\x01\n\x13\x43reateRepositoryTag\x12\x35.artifact.artifact.v1alpha.CreateRepositoryTagRequest\x1a\x36.artifact.artifact.v1alpha.CreateRepositoryTagResponse\x12\x84\x01\n\x13\x44\x65leteRepositoryTag\x12\x35.artifact.artifact.v1alpha.DeleteRepositoryTagRequest\x1a\x36.artifact.artifact.v1alpha.DeleteRepositoryTagResponseB\x8f\x02\n\x1d\x63om.artifact.artifact.v1alphaB\x1b\x41rtifactPrivateServiceProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.artifact_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\033ArtifactPrivateServiceProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _globals['_ARTIFACTPRIVATESERVICE']._serialized_start=130
  _globals['_ARTIFACTPRIVATESERVICE']._serialized_end=681
# @@protoc_insertion_point(module_scope)



# pylint: disable=no-name-in-module
from instill.clients.artifact import ArtifactClient
from instill.clients.mgmt import MgmtClient
from instill.clients.model import ModelClient
from instill.clients.pipeline import PipelineClient
from instill.utils.error_handler import NotServingException
from instill.utils.logger import Logger


class InstillClient:
    def __init__(self, async_enabled: bool = False) -> None:
        self.mgmt_service = MgmtClient(async_enabled=async_enabled)
        if not self.mgmt_service.is_serving():
            Logger.w("Instill Core is required")
            raise NotServingException

        user_name = self.mgmt_service.get_user().user.name

        self.pipeline_service = PipelineClient(
            namespace=user_name,
            async_enabled=async_enabled,
        )
        if not self.pipeline_service.is_serving():
            Logger.w("Instill VDP is not serving, VDP functionalities will not work")

        self.model_service = ModelClient(
            namespace=user_name,
            async_enabled=async_enabled,
        )
        if not self.model_service.is_serving():
            Logger.w(
                "Instill Model is not serving, Model functionalities will not work"
            )

        self.artifact_service = ArtifactClient(async_enabled=async_enabled)
        if not self.artifact_service.is_serving():
            Logger.w(
                "Instill Artifact is not serving, Artifact functionalities will not work"
            )

    def set_instance(self, instance: str):
        self.mgmt_service.instance = instance
        self.pipeline_service.instance = instance
        self.model_service.instance = instance
        self.artifact_service.instance = instance

    def close(self):
        if self.mgmt_service.is_serving():
            for host in self.mgmt_service.hosts.values():
                host.channel.close()
        if self.pipeline_service.is_serving():
            for host in self.pipeline_service.hosts.values():
                host.channel.close()
        if self.model_service.is_serving():
            for host in self.model_service.hosts.values():
                host.channel.close()
        if self.artifact_service.is_serving():
            for host in self.artifact_service.hosts.values():
                host.channel.close()

    async def async_close(self):
        if self.mgmt_service.is_serving():
            for host in self.mgmt_service.hosts.values():
                await host.async_channel.close()
        if self.pipeline_service.is_serving():
            for host in self.pipeline_service.hosts.values():
                await host.async_channel.close()
        if self.model_service.is_serving():
            for host in self.model_service.hosts.values():
                await host.async_channel.close()
        if self.artifact_service.is_serving():
            for host in self.artifact_service.hosts.values():
                await host.async_channel.close()


def get_client(async_enabled: bool = False) -> InstillClient:
    return InstillClient(async_enabled=async_enabled)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_unspecified.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*model/model/v1alpha/task_unspecified.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\"J\n\x10UnspecifiedInput\x12\x36\n\nraw_inputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\trawInputs\"S\n\x11UnspecifiedOutput\x12>\n\x0braw_outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\nrawOutputsB\xe1\x01\n\x17\x63om.model.model.v1alphaB\x14TaskUnspecifiedProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_unspecified_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\024TaskUnspecifiedProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _UNSPECIFIEDOUTPUT.fields_by_name['raw_outputs']._options = None
  _UNSPECIFIEDOUTPUT.fields_by_name['raw_outputs']._serialized_options = b'\342A\001\003'
  _globals['_UNSPECIFIEDINPUT']._serialized_start=130
  _globals['_UNSPECIFIEDINPUT']._serialized_end=204
  _globals['_UNSPECIFIEDOUTPUT']._serialized_start=206
  _globals['_UNSPECIFIEDOUTPUT']._serialized_end=289
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Role:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Role.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ROLE_UNSPECIFIED: _Role.ValueType  # 0
    """Unspecified, equivalent to VIEWER."""
    ROLE_VIEWER: _Role.ValueType  # 1
    """Viewers can see the resource properties."""
    ROLE_EXECUTOR: _Role.ValueType  # 2
    """Executors can execute the resource (e.g. trigger a pipeline)."""

class Role(_Role, metaclass=_RoleEnumTypeWrapper):
    """Role describes the permissions a user has over a resource."""

ROLE_UNSPECIFIED: Role.ValueType  # 0
"""Unspecified, equivalent to VIEWER."""
ROLE_VIEWER: Role.ValueType  # 1
"""Viewers can see the resource properties."""
ROLE_EXECUTOR: Role.ValueType  # 2
"""Executors can execute the resource (e.g. trigger a pipeline)."""
global___Role = Role

class _ComponentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ComponentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ComponentType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMPONENT_TYPE_UNSPECIFIED: _ComponentType.ValueType  # 0
    """Unspecified."""
    COMPONENT_TYPE_AI: _ComponentType.ValueType  # 1
    """Connect with an AI model."""
    COMPONENT_TYPE_DATA: _ComponentType.ValueType  # 2
    """Connect with a remote data source."""
    COMPONENT_TYPE_OPERATOR: _ComponentType.ValueType  # 4
    """Manipulate data."""
    COMPONENT_TYPE_APPLICATION: _ComponentType.ValueType  # 5
    """Connect with an external application."""
    COMPONENT_TYPE_GENERIC: _ComponentType.ValueType  # 6
    """Generic."""

class ComponentType(_ComponentType, metaclass=_ComponentTypeEnumTypeWrapper):
    """ComponentType defines the component type based on its task features."""

COMPONENT_TYPE_UNSPECIFIED: ComponentType.ValueType  # 0
"""Unspecified."""
COMPONENT_TYPE_AI: ComponentType.ValueType  # 1
"""Connect with an AI model."""
COMPONENT_TYPE_DATA: ComponentType.ValueType  # 2
"""Connect with a remote data source."""
COMPONENT_TYPE_OPERATOR: ComponentType.ValueType  # 4
"""Manipulate data."""
COMPONENT_TYPE_APPLICATION: ComponentType.ValueType  # 5
"""Connect with an external application."""
COMPONENT_TYPE_GENERIC: ComponentType.ValueType  # 6
"""Generic."""
global___ComponentType = ComponentType

@typing_extensions.final
class Sharing(google.protobuf.message.Message):
    """Sharing contains the information to share a resource with other users.

    For more information, see [Share Pipelines](https://www.instill.tech/docs/vdp/share).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class User(google.protobuf.message.Message):
        """Describes the sharing configuration with a given user."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        ROLE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """Defines whether the sharing option with this user is enabled."""
        role: global___Role.ValueType
        """Defines the role the user will have over the resource."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            role: global___Role.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "role", b"role"]) -> None: ...

    @typing_extensions.final
    class ShareCode(google.protobuf.message.Message):
        """ShareCode describes a sharing configuration through a link."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        USER_FIELD_NUMBER: builtins.int
        CODE_FIELD_NUMBER: builtins.int
        ENABLED_FIELD_NUMBER: builtins.int
        ROLE_FIELD_NUMBER: builtins.int
        user: builtins.str
        """Defines which users will be able to access the resource through the
        code. This is a pattern that will be checked against user names.

        For now, the only accepted value is `*/*`.
        """
        code: builtins.str
        """The public URL that allows users to access the resource."""
        enabled: builtins.bool
        """Defines whether the sharing option via link is enabled."""
        role: global___Role.ValueType
        """Defines the role users will have over the resource."""
        def __init__(
            self,
            *,
            user: builtins.str = ...,
            code: builtins.str = ...,
            enabled: builtins.bool = ...,
            role: global___Role.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "enabled", b"enabled", "role", b"role", "user", b"user"]) -> None: ...

    @typing_extensions.final
    class UsersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Sharing.User: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Sharing.User | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    USERS_FIELD_NUMBER: builtins.int
    SHARE_CODE_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Sharing.User]:
        """Defines sharing rules for a set of user resource names.

        Each key in this object should contain a pattern that can be matched
        against user names.

        Each value is a user sharing configuration.

        **NOTE**: For now, the only accepted key is `*/*`.
        """
    @property
    def share_code(self) -> global___Sharing.ShareCode:
        """Defines the configuration to share a resource via link."""
    def __init__(
        self,
        *,
        users: collections.abc.Mapping[builtins.str, global___Sharing.User] | None = ...,
        share_code: global___Sharing.ShareCode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["share_code", b"share_code"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_code", b"share_code", "users", b"users"]) -> None: ...

global___Sharing = Sharing

@typing_extensions.final
class Permission(google.protobuf.message.Message):
    """Permission defines how a pipeline can be used."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAN_EDIT_FIELD_NUMBER: builtins.int
    CAN_TRIGGER_FIELD_NUMBER: builtins.int
    CAN_RELEASE_FIELD_NUMBER: builtins.int
    can_edit: builtins.bool
    """Defines whether the pipeline can be modified."""
    can_trigger: builtins.bool
    """Defines whether the pipeline can be executed."""
    can_release: builtins.bool
    """Defines whether the pipeline can be released."""
    def __init__(
        self,
        *,
        can_edit: builtins.bool = ...,
        can_trigger: builtins.bool = ...,
        can_release: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_edit", b"can_edit", "can_release", b"can_release", "can_trigger", b"can_trigger"]) -> None: ...

global___Permission = Permission

@typing_extensions.final
class CheckNameRequest(google.protobuf.message.Message):
    """CheckNameRequest represents a request to verify if a name is
    available.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the resource to be checked. For the moment, only pipeline and
    connector names can be checked. The following formats are accepted:
    - `users/{user.id}/pipelines/{pipeline.id}`
    - `users/{user.id}/connectors/{connector.id}`
    - `organizations/{organization.id}/pipelines/{pipeline.id}`
    - `organizations/{organization.id}/connectors/{connector.id}`
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CheckNameRequest = CheckNameRequest

@typing_extensions.final
class CheckNameResponse(google.protobuf.message.Message):
    """CheckNameResponse contains the availability of a resource name."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Name:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _NameEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CheckNameResponse._Name.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NAME_UNSPECIFIED: CheckNameResponse._Name.ValueType  # 0
        """Unspecified."""
        NAME_AVAILABLE: CheckNameResponse._Name.ValueType  # 1
        """Available."""
        NAME_UNAVAILABLE: CheckNameResponse._Name.ValueType  # 2
        """Unavailable."""

    class Name(_Name, metaclass=_NameEnumTypeWrapper):
        """Name defines the availability of a resource name."""

    NAME_UNSPECIFIED: CheckNameResponse.Name.ValueType  # 0
    """Unspecified."""
    NAME_AVAILABLE: CheckNameResponse.Name.ValueType  # 1
    """Available."""
    NAME_UNAVAILABLE: CheckNameResponse.Name.ValueType  # 2
    """Unavailable."""

    AVAILABILITY_FIELD_NUMBER: builtins.int
    availability: global___CheckNameResponse.Name.ValueType
    """The availability of the requested name."""
    def __init__(
        self,
        *,
        availability: global___CheckNameResponse.Name.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability", b"availability"]) -> None: ...

global___CheckNameResponse = CheckNameResponse

@typing_extensions.final
class ComponentTask(google.protobuf.message.Message):
    """ComponentTask contains information about a task that a component can
    perform.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The task name, e.g. `TASK_TEXT_GENERATION`."""
    title: builtins.str
    """Title is the task name in a human-friendly format."""
    description: builtins.str
    """Description contains information about the task."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "title", b"title"]) -> None: ...

global___ComponentTask = ComponentTask



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ClassificationInput(google.protobuf.message.Message):
    """ClassificationInput is the input of an image classification task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URL_FIELD_NUMBER: builtins.int
    IMAGE_BASE64_FIELD_NUMBER: builtins.int
    image_url: builtins.str
    """Image URL."""
    image_base64: builtins.str
    """Base64-encoded image."""
    def __init__(
        self,
        *,
        image_url: builtins.str = ...,
        image_base64: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image_base64", b"image_base64", "image_url", b"image_url", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_base64", b"image_base64", "image_url", b"image_url", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["image_url", "image_base64"] | None: ...

global___ClassificationInput = ClassificationInput

@typing_extensions.final
class ClassificationInputStream(google.protobuf.message.Message):
    """ClassificationInputStream represents the input of an image classification
    task when the input is streamed as a binary files.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_LENGTHS_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def file_lengths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """File length for each uploaded binary file."""
    content: builtins.bytes
    """Byte representation of the images."""
    def __init__(
        self,
        *,
        file_lengths: collections.abc.Iterable[builtins.int] | None = ...,
        content: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "file_lengths", b"file_lengths"]) -> None: ...

global___ClassificationInputStream = ClassificationInputStream

@typing_extensions.final
class ClassificationOutput(google.protobuf.message.Message):
    """ClassificationOutput contains the result of an image classification task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORY_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    category: builtins.str
    """Category."""
    score: builtins.float
    """Score."""
    def __init__(
        self,
        *,
        category: builtins.str = ...,
        score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "score", b"score"]) -> None: ...

global___ClassificationOutput = ClassificationOutput



import argparse

# import hashlib
import os
import platform
import shutil
import subprocess
import tempfile

import ray
import yaml

import instill
from instill.helpers.const import DEFAULT_DEPENDENCIES
from instill.helpers.errors import ModelConfigException
from instill.utils.logger import Logger


def config_check_required_fields(c):
    if "build" not in c or c["build"] is None:
        raise ModelConfigException("build")
    if "gpu" not in c["build"] or c["build"]["gpu"] is None:
        raise ModelConfigException("gpu")
    if "python_version" not in c["build"] or c["build"]["python_version"] is None:
        raise ModelConfigException("python_version")


def cli():
    if platform.machine() in ("i386", "AMD64", "x86_64"):
        default_platform = "amd64"
    else:
        default_platform = platform.machine()
    parser = argparse.ArgumentParser()
    subcommands = parser.add_subparsers(required=True)

    # init
    init_parser = subcommands.add_parser("init", help="Initialize model directory")
    init_parser.set_defaults(func=init)

    # build
    build_parser = subcommands.add_parser("build", help="Build model image")
    build_parser.set_defaults(func=build)
    build_parser.add_argument(
        "name",
        help="user and model namespace, in the format of <user-id>/<model-id>",
    )
    build_parser.add_argument(
        "-t",
        "--tag",
        help="tag for the model image, default to `latest`",
        # default=hashlib.sha256().hexdigest(),
        default="latest",
        required=False,
    )
    build_parser.add_argument(
        "--no-cache",
        help="build the image without cache",
        action="store_true",
        required=False,
    )
    build_parser.add_argument(
        "--target-arch",
        help="target platform architecture for the model image, default to host",
        default=default_platform,
        choices=["arm64", "amd64"],
        required=False,
    )

    # push
    push_parser = subcommands.add_parser("push", help="Push model image")
    push_parser.set_defaults(func=push)
    push_parser.add_argument(
        "name",
        help="user and model namespace, in the format of <user-id>/<model-id>",
    )
    push_parser.add_argument(
        "-u",
        "--url",
        help="image registry url, in the format of host:port, default to api.instill.tech",
        default="api.instill.tech",
        required=False,
    )
    push_parser.add_argument(
        "-t",
        "--tag",
        help="tag for the model image, default to `latest`",
        default="latest",
        required=False,
    )

    args = parser.parse_args()
    args.func(args)


def init(_):
    shutil.copyfile(
        __file__.replace("cli.py", "init-templates/instill.yaml"),
        f"{os.getcwd()}/instill.yaml",
    )
    shutil.copyfile(
        __file__.replace("cli.py", "init-templates/model.py"),
        f"{os.getcwd()}/model.py",
    )
    shutil.copyfile(
        __file__.replace("cli.py", "init-templates/.dockerignore"),
        f"{os.getcwd()}/.dockerignore",
    )


def build(args):
    try:
        Logger.i("[Instill Builder] Loading config file...")
        with open("instill.yaml", "r", encoding="utf8") as f:
            Logger.i("[Instill Builder] Parsing config file...")
            config = yaml.safe_load(f)

        config_check_required_fields(config)

        build_params = config["build"]

        python_version = build_params["python_version"].replace(".", "")
        ray_version = ray.__version__
        instill_version = instill.__version__

        if not build_params["gpu"]:
            cuda_suffix = ""
        elif (
            "cuda_version" in build_params and not build_params["cuda_version"] is None
        ):
            cuda_suffix = f'-cu{build_params["cuda_version"].replace(".", "")}'
        else:
            cuda_suffix = "-gpu"

        system_str = ""
        if (
            "system_packages" in build_params
            and not build_params["system_packages"] is None
        ):
            for p in build_params["system_packages"]:
                system_str += p + " "

        packages_str = ""
        if (
            "python_packages" in build_params
            and not build_params["python_packages"] is None
        ):
            for p in build_params["python_packages"]:
                packages_str += p + " "
        for p in DEFAULT_DEPENDENCIES:
            packages_str += p + " "
        packages_str += f"instill-sdk=={instill_version}"

        with tempfile.TemporaryDirectory() as tmpdir:
            shutil.copyfile(
                __file__.replace("cli.py", "init-templates/Dockerfile"),
                f"{tmpdir}/Dockerfile",
            )
            shutil.copytree(os.getcwd(), tmpdir, dirs_exist_ok=True)

            target_arch_suffix = "-aarch64" if args.target_arch == "arm64" else ""

            Logger.i("[Instill Builder] Building model image...")
            command = [
                "docker",
                "buildx",
                "build",
                "--build-arg",
                f"TARGET_ARCH_SUFFIX={target_arch_suffix}",
                "--build-arg",
                f"RAY_VERSION={ray_version}",
                "--build-arg",
                f"PYTHON_VERSION={python_version}",
                "--build-arg",
                f"CUDA_SUFFIX={cuda_suffix}",
                "--build-arg",
                f"PACKAGES={packages_str}",
                "--build-arg",
                f"SYSTEM_PACKAGES={system_str}",
                "--platform",
                f"linux/{args.target_arch}",
                "-t",
                f"{args.name}:{args.tag}",
                tmpdir,
                "--load",
            ]
            if args.no_cache:
                command.append("--no-cache")
            subprocess.run(
                command,
                check=True,
            )
            Logger.i(f"[Instill Builder] {args.name}:{args.tag} built")
    except subprocess.CalledProcessError:
        Logger.e("[Instill Builder] Build failed")
    except Exception as e:
        Logger.e("[Instill Builder] Prepare failed")
        Logger.e(e)
    finally:
        Logger.i("[Instill Builder] Done")


def push(args):
    try:
        registry = args.url

        subprocess.run(
            [
                "docker",
                "tag",
                f"{args.name}:{args.tag}",
                f"{registry}/{args.name}:{args.tag}",
            ],
            check=True,
        )
        Logger.i("[Instill Builder] Pushing model image...")
        subprocess.run(
            ["docker", "push", f"{registry}/{args.name}:{args.tag}"], check=True
        )
        Logger.i(f"[Instill Builder] {registry}/{args.name}:{args.tag} pushed")
    except subprocess.CalledProcessError:
        Logger.e("[Instill Builder] Push failed")
    except Exception as e:
        Logger.e("[Instill Builder] Prepare failed")
        Logger.e(e)
    finally:
        Logger.i("[Instill Builder] Done")


if __name__ == "__main__":
    cli()



class ModelPathException(Exception):
    def __str__(self) -> str:
        return "model path is not valid"


class ModelVramException(Exception):
    def __str__(self) -> str:
        return "model projected vram usage is more than the GPU can handle"


class ModelConfigException(Exception):
    def __init__(self, field):
        self.field = field

    def __str__(
        self,
    ) -> str:
        return f"model config file `instill.yaml` is missing {self.field} field"



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import model.model.v1alpha.common_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TextGenerationChatInput(google.protobuf.message.Message):
    """TextGenerationChatInput represents the input of a text generation chat task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_FIELD_NUMBER: builtins.int
    PROMPT_IMAGES_FIELD_NUMBER: builtins.int
    CHAT_HISTORY_FIELD_NUMBER: builtins.int
    SYSTEM_MESSAGE_FIELD_NUMBER: builtins.int
    MAX_NEW_TOKENS_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    TOP_K_FIELD_NUMBER: builtins.int
    SEED_FIELD_NUMBER: builtins.int
    EXTRA_PARAMS_FIELD_NUMBER: builtins.int
    prompt: builtins.str
    """Prompt text."""
    @property
    def prompt_images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[model.model.v1alpha.common_pb2.PromptImage]:
        """Prompt images."""
    @property
    def chat_history(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[model.model.v1alpha.common_pb2.Message]:
        """Chat history."""
    system_message: builtins.str
    """System message, which sets the behaviour of the assistant."""
    max_new_tokens: builtins.int
    """Maximum number of generation tokens."""
    temperature: builtins.float
    """Sampling temperature."""
    top_k: builtins.int
    """Sampling Top K, number of tokens at the top from which the model will
    sample.
    """
    seed: builtins.int
    """Seed."""
    @property
    def extra_params(self) -> google.protobuf.struct_pb2.Struct:
        """Extra parameters."""
    def __init__(
        self,
        *,
        prompt: builtins.str = ...,
        prompt_images: collections.abc.Iterable[model.model.v1alpha.common_pb2.PromptImage] | None = ...,
        chat_history: collections.abc.Iterable[model.model.v1alpha.common_pb2.Message] | None = ...,
        system_message: builtins.str | None = ...,
        max_new_tokens: builtins.int | None = ...,
        temperature: builtins.float | None = ...,
        top_k: builtins.int | None = ...,
        seed: builtins.int | None = ...,
        extra_params: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_max_new_tokens", b"_max_new_tokens", "_seed", b"_seed", "_system_message", b"_system_message", "_temperature", b"_temperature", "_top_k", b"_top_k", "extra_params", b"extra_params", "max_new_tokens", b"max_new_tokens", "seed", b"seed", "system_message", b"system_message", "temperature", b"temperature", "top_k", b"top_k"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_max_new_tokens", b"_max_new_tokens", "_seed", b"_seed", "_system_message", b"_system_message", "_temperature", b"_temperature", "_top_k", b"_top_k", "chat_history", b"chat_history", "extra_params", b"extra_params", "max_new_tokens", b"max_new_tokens", "prompt", b"prompt", "prompt_images", b"prompt_images", "seed", b"seed", "system_message", b"system_message", "temperature", b"temperature", "top_k", b"top_k"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_max_new_tokens", b"_max_new_tokens"]) -> typing_extensions.Literal["max_new_tokens"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_seed", b"_seed"]) -> typing_extensions.Literal["seed"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_system_message", b"_system_message"]) -> typing_extensions.Literal["system_message"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_temperature", b"_temperature"]) -> typing_extensions.Literal["temperature"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_top_k", b"_top_k"]) -> typing_extensions.Literal["top_k"] | None: ...

global___TextGenerationChatInput = TextGenerationChatInput

@typing_extensions.final
class TextGenerationChatOutput(google.protobuf.message.Message):
    """TextGenerationChatOutput contains the result of a text generation chat task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text generated by the model."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text"]) -> None: ...

global___TextGenerationChatOutput = TextGenerationChatOutput



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_instance_segmentation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from model.model.v1alpha import common_pb2 as model_dot_model_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4model/model/v1alpha/task_instance_segmentation.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a model/model/v1alpha/common.proto\"\xbd\x01\n\x1aInstanceSegmentationObject\x12\x16\n\x03rle\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x03rle\x12 \n\x08\x63\x61tegory\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x08\x63\x61tegory\x12\x1a\n\x05score\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x05score\x12I\n\x0c\x62ounding_box\x18\x04 \x01(\x0b\x32 .model.model.v1alpha.BoundingBoxB\x04\xe2\x41\x01\x03R\x0b\x62oundingBox\"g\n\x19InstanceSegmentationInput\x12\x1d\n\timage_url\x18\x01 \x01(\tH\x00R\x08imageUrl\x12#\n\x0cimage_base64\x18\x02 \x01(\tH\x00R\x0bimageBase64B\x06\n\x04type\"j\n\x1fInstanceSegmentationInputStream\x12\'\n\x0c\x66ile_lengths\x18\x01 \x03(\rB\x04\xe2\x41\x01\x02R\x0b\x66ileLengths\x12\x1e\n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\x07\x63ontent\"m\n\x1aInstanceSegmentationOutput\x12O\n\x07objects\x18\x01 \x03(\x0b\x32/.model.model.v1alpha.InstanceSegmentationObjectB\x04\xe2\x41\x01\x03R\x07objectsB\xea\x01\n\x17\x63om.model.model.v1alphaB\x1dTaskInstanceSegmentationProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_instance_segmentation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\035TaskInstanceSegmentationProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['rle']._options = None
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['rle']._serialized_options = b'\342A\001\003'
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['category']._options = None
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['category']._serialized_options = b'\342A\001\003'
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['score']._options = None
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['score']._serialized_options = b'\342A\001\003'
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['bounding_box']._options = None
  _INSTANCESEGMENTATIONOBJECT.fields_by_name['bounding_box']._serialized_options = b'\342A\001\003'
  _INSTANCESEGMENTATIONINPUTSTREAM.fields_by_name['file_lengths']._options = None
  _INSTANCESEGMENTATIONINPUTSTREAM.fields_by_name['file_lengths']._serialized_options = b'\342A\001\002'
  _INSTANCESEGMENTATIONINPUTSTREAM.fields_by_name['content']._options = None
  _INSTANCESEGMENTATIONINPUTSTREAM.fields_by_name['content']._serialized_options = b'\342A\001\002'
  _INSTANCESEGMENTATIONOUTPUT.fields_by_name['objects']._options = None
  _INSTANCESEGMENTATIONOUTPUT.fields_by_name['objects']._serialized_options = b'\342A\001\003'
  _globals['_INSTANCESEGMENTATIONOBJECT']._serialized_start=145
  _globals['_INSTANCESEGMENTATIONOBJECT']._serialized_end=334
  _globals['_INSTANCESEGMENTATIONINPUT']._serialized_start=336
  _globals['_INSTANCESEGMENTATIONINPUT']._serialized_end=439
  _globals['_INSTANCESEGMENTATIONINPUTSTREAM']._serialized_start=441
  _globals['_INSTANCESEGMENTATIONINPUTSTREAM']._serialized_end=547
  _globals['_INSTANCESEGMENTATIONOUTPUT']._serialized_start=549
  _globals['_INSTANCESEGMENTATIONOUTPUT']._serialized_end=658
# @@protoc_insertion_point(module_scope)
